#!/usr/bin/env Rscript
args = commandArgs(trailingOnly=TRUE)
if (length(args)<7) {
  stop("7 argument must be supplied", call.=FALSE)
}

options(bitmapType='cairo')
efffn <- args[1] #'b01c.ref.snpRes'
effheader <- as.logical(args[2]) #'T/F'
effcoln <- args[3] #'A1Effect'
bvfn <- args[4] #'b01c.val.bayesr.profile'
phefn <- args[5] #'b01c.val.phen'
outpath <- args[6] #'.'
outpref <- args[7] #'bayesr'

#---plot effect distribution
effdt <- read.table(efffn,header=effheader)
plotdt <- effdt[,grep(paste0('^',effcoln,'$'),colnames(effdt))]
pngn <- paste0(outpath,'/',outpref,'.effhist.png')
png(pngn,450,500)
hist(plotdt, main=paste0('histogram for ',outpref),breaks=100,xlim=c(-1.1,1.1))
abline(v = mean(plotdt,na.rm=T), col = "blue", lwd = 2)
dev.off()
cat(paste0('Effect histogram saved to ',pngn),sep='\n')

#----estimate correlation between ebv and phenotype
bv <- read.table(bvfn,header=T)
phen <- read.table(phefn,header=F)
colnames(phen)[3] <- 'phenotype'
mgdt <- merge(bv,phen,by.x='IID',by.y='V2',sort=F)
x <- mgdt[,grep('SCORE',colnames(mgdt))]
y <-  mgdt[,grep('phenotype',colnames(mgdt))]
accr <- round(cor(y,x,use='pairwise.complete.obs'),4)
cat(paste0('Prediction accuracy (r) is ',accr),sep='\n')
#----plot correlation between ebv and phenotype
pngn <- paste0(outpath,'/',outpref,'.corr.png')
png(pngn,450,500)
plot(x, y, main=paste0('EBV VS phenotype for ',outpref),xlab=paste0('EBV using ', outpref),ylab='Phenotype',cex.lab=1.5)
abline(lm(y~x), col="red")
text(paste("Correlation:", round(cor(x, y), 2)), x = -30, y = 150,cex=1.2)
dev.off()
cat(paste0('Regression plot saved to ',pngn),sep='\n')

