###############################################################################
#====================code Gibbs lm====================================
###############################################################################
.libPaths("C:/Users/Public/Rlib")
setwd("C:/Users/rx01/teach/stats_lecture1_Nov2021")
library(ggplot2)
set.seed(2)

#simulate a trait
phe <- rnorm(100,1000,500)
head(phe,10)
SNP <- sample(rep(c(0,1,2),500),100)
head(SNP,50)

#----set up function
mcmc.lr <- function(Y,X,Intcept,Slope,s2,mu0,alpha.0,beta.0,s20,nit){
  n <- length(Y)
  sampl <- matrix(0,nit,3)
  colnames(sampl) <- c("Intcept","Slope","sigma2")
  sampl[1,] <- c(Intcept,Slope,s2)
  for(iter in 2:nit){
    #sample Intcept
    V <- n/s2+mu0/s20
    M <- sum(Y-X*Slope)/s2+1/s20
    Intcept <- rnorm(1,M/V,1/sqrt(V))
    
    #sample Slope
    V <- sum(X^2)/s2+mu0/s20
    M <- sum(X*(Y-Intcept))/s2+1/s20
    Slope  <- rnorm(1,M/V,1/sqrt(V))
    
    #sample s2|mu,Y,Z
    A <- n/2 + alpha.0
    B <- sum((Y-Intcept-X*Slope)^2)/2 + beta.0
    s2 <- 1/rgamma(1,A,B)
    
    #keep track of the results
    sampl[iter,] <- c(Intcept,Slope,s2)
  }  
 return(sampl) 
}

### Priors
mu0 <- 0
s20 <- 1000
alpha.0   <- 0.01
beta.0   <- 0.01

# Initial values
Intcept <- 1
Slope <- 1
s2 <- 1

#----number of iterations
nit <- 5000
nb <- 2000

res <- mcmc.lr(phe,SNP,Intcept,Slope,s2,mu0,alpha.0,beta.0,s20,nit)
head(res)

data.frame(Mean=colMeans(res[nb:nit,]),SD=apply(res[nb:nit,],2,sd))

#---frequentist approach
lm(phe ~ SNP)

#---histograms
hist(res[,1],breaks = 100,main="Intercept")
abline(v=mean(res[,1]),col="blue")

hist(res[,2],breaks = 100,main="Slope")
abline(v=mean(res[,2]),col="blue")

hist(res[,3],breaks = 100,main="sigma2")
abline(v=mean(res[,3]),col="blue")

#---iterations
plot(res[,1]/(1:nit), type="l", main="Intercept", ylab="", xlab='')
plot(res[,2]/(1:nit), type="l", main="Slope", ylab="", xlab='')
plot(res[,3]/(1:nit), type="l", main="sigma2", ylab="", xlab='')
